@@ -13,9 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.documentai_v1.types import geometry
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
 from google.type import color_pb2  # type: ignore
@@ -23,10 +20,15 @@ from google.type import date_pb2  # type: ignore
 from google.type import datetime_pb2  # type: ignore
 from google.type import money_pb2  # type: ignore
 from google.type import postal_address_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.documentai_v1.types import geometry
 
 __protobuf__ = proto.module(
-    package="google.cloud.documentai.v1", manifest={"Document",},
+    package="google.cloud.documentai.v1",
+    manifest={
+        "Document",
+    },
 )
 
 
@@ -114,9 +116,18 @@ class Document(proto.Message):
                 the overall document global text.
         """
 
-        shard_index = proto.Field(proto.INT64, number=1,)
-        shard_count = proto.Field(proto.INT64, number=2,)
-        text_offset = proto.Field(proto.INT64, number=3,)
+        shard_index = proto.Field(
+            proto.INT64,
+            number=1,
+        )
+        shard_count = proto.Field(
+            proto.INT64,
+            number=2,
+        )
+        text_offset = proto.Field(
+            proto.INT64,
+            number=3,
+        )
 
     class Style(proto.Message):
         r"""Annotation for common text style attributes. This adheres to
@@ -154,21 +165,46 @@ class Document(proto.Message):
                     (in, px, pt, etc.).
             """
 
-            size = proto.Field(proto.FLOAT, number=1,)
-            unit = proto.Field(proto.STRING, number=2,)
+            size = proto.Field(
+                proto.FLOAT,
+                number=1,
+            )
+            unit = proto.Field(
+                proto.STRING,
+                number=2,
+            )
 
         text_anchor = proto.Field(
-            proto.MESSAGE, number=1, message="Document.TextAnchor",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor",
+        )
+        color = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=color_pb2.Color,
         )
-        color = proto.Field(proto.MESSAGE, number=2, message=color_pb2.Color,)
         background_color = proto.Field(
-            proto.MESSAGE, number=3, message=color_pb2.Color,
+            proto.MESSAGE,
+            number=3,
+            message=color_pb2.Color,
+        )
+        font_weight = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        text_style = proto.Field(
+            proto.STRING,
+            number=5,
+        )
+        text_decoration = proto.Field(
+            proto.STRING,
+            number=6,
         )
-        font_weight = proto.Field(proto.STRING, number=4,)
-        text_style = proto.Field(proto.STRING, number=5,)
-        text_decoration = proto.Field(proto.STRING, number=6,)
         font_size = proto.Field(
-            proto.MESSAGE, number=7, message="Document.Style.FontSize",
+            proto.MESSAGE,
+            number=7,
+            message="Document.Style.FontSize",
         )
 
     class Page(proto.Message):
@@ -243,9 +279,18 @@ class Document(proto.Message):
                     Dimension unit.
             """
 
-            width = proto.Field(proto.FLOAT, number=1,)
-            height = proto.Field(proto.FLOAT, number=2,)
-            unit = proto.Field(proto.STRING, number=3,)
+            width = proto.Field(
+                proto.FLOAT,
+                number=1,
+            )
+            height = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
+            unit = proto.Field(
+                proto.STRING,
+                number=3,
+            )
 
         class Image(proto.Message):
             r"""Rendered image contents for this page.
@@ -261,10 +306,22 @@ class Document(proto.Message):
                     Height of the image in pixels.
             """
 
-            content = proto.Field(proto.BYTES, number=1,)
-            mime_type = proto.Field(proto.STRING, number=2,)
-            width = proto.Field(proto.INT32, number=3,)
-            height = proto.Field(proto.INT32, number=4,)
+            content = proto.Field(
+                proto.BYTES,
+                number=1,
+            )
+            mime_type = proto.Field(
+                proto.STRING,
+                number=2,
+            )
+            width = proto.Field(
+                proto.INT32,
+                number=3,
+            )
+            height = proto.Field(
+                proto.INT32,
+                number=4,
+            )
 
         class Matrix(proto.Message):
             r"""Representation for transformation matrix, intended to be
@@ -285,10 +342,22 @@ class Document(proto.Message):
                     The matrix data.
             """
 
-            rows = proto.Field(proto.INT32, number=1,)
-            cols = proto.Field(proto.INT32, number=2,)
-            type_ = proto.Field(proto.INT32, number=3,)
-            data = proto.Field(proto.BYTES, number=4,)
+            rows = proto.Field(
+                proto.INT32,
+                number=1,
+            )
+            cols = proto.Field(
+                proto.INT32,
+                number=2,
+            )
+            type_ = proto.Field(
+                proto.INT32,
+                number=3,
+            )
+            data = proto.Field(
+                proto.BYTES,
+                number=4,
+            )
 
         class Layout(proto.Message):
             r"""Visual element describing a layout unit on a page.
@@ -320,14 +389,23 @@ class Document(proto.Message):
                 PAGE_LEFT = 4
 
             text_anchor = proto.Field(
-                proto.MESSAGE, number=1, message="Document.TextAnchor",
+                proto.MESSAGE,
+                number=1,
+                message="Document.TextAnchor",
+            )
+            confidence = proto.Field(
+                proto.FLOAT,
+                number=2,
             )
-            confidence = proto.Field(proto.FLOAT, number=2,)
             bounding_poly = proto.Field(
-                proto.MESSAGE, number=3, message=geometry.BoundingPoly,
+                proto.MESSAGE,
+                number=3,
+                message=geometry.BoundingPoly,
             )
             orientation = proto.Field(
-                proto.ENUM, number=4, enum="Document.Page.Layout.Orientation",
+                proto.ENUM,
+                number=4,
+                enum="Document.Page.Layout.Orientation",
             )
 
         class Block(proto.Message):
@@ -346,13 +424,19 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
             provenance = proto.Field(
-                proto.MESSAGE, number=3, message="Document.Provenance",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Provenance",
             )
 
         class Paragraph(proto.Message):
@@ -372,13 +456,19 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
             provenance = proto.Field(
-                proto.MESSAGE, number=3, message="Document.Provenance",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Provenance",
             )
 
         class Line(proto.Message):
@@ -398,13 +488,19 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
             provenance = proto.Field(
-                proto.MESSAGE, number=3, message="Document.Provenance",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Provenance",
             )
 
         class Token(proto.Message):
@@ -441,20 +537,30 @@ class Document(proto.Message):
                     HYPHEN = 3
 
                 type_ = proto.Field(
-                    proto.ENUM, number=1, enum="Document.Page.Token.DetectedBreak.Type",
+                    proto.ENUM,
+                    number=1,
+                    enum="Document.Page.Token.DetectedBreak.Type",
                 )
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_break = proto.Field(
-                proto.MESSAGE, number=2, message="Document.Page.Token.DetectedBreak",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Token.DetectedBreak",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
             provenance = proto.Field(
-                proto.MESSAGE, number=4, message="Document.Provenance",
+                proto.MESSAGE,
+                number=4,
+                message="Document.Provenance",
             )
 
         class Symbol(proto.Message):
@@ -471,10 +577,14 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
 
         class VisualElement(proto.Message):
@@ -495,11 +605,18 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
+            )
+            type_ = proto.Field(
+                proto.STRING,
+                number=2,
             )
-            type_ = proto.Field(proto.STRING, number=2,)
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
 
         class Table(proto.Message):
@@ -527,7 +644,9 @@ class Document(proto.Message):
                 """
 
                 cells = proto.RepeatedField(
-                    proto.MESSAGE, number=1, message="Document.Page.Table.TableCell",
+                    proto.MESSAGE,
+                    number=1,
+                    message="Document.Page.Table.TableCell",
                 )
 
             class TableCell(proto.Message):
@@ -548,25 +667,43 @@ class Document(proto.Message):
                 """
 
                 layout = proto.Field(
-                    proto.MESSAGE, number=1, message="Document.Page.Layout",
+                    proto.MESSAGE,
+                    number=1,
+                    message="Document.Page.Layout",
+                )
+                row_span = proto.Field(
+                    proto.INT32,
+                    number=2,
+                )
+                col_span = proto.Field(
+                    proto.INT32,
+                    number=3,
                 )
-                row_span = proto.Field(proto.INT32, number=2,)
-                col_span = proto.Field(proto.INT32, number=3,)
                 detected_languages = proto.RepeatedField(
-                    proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                    proto.MESSAGE,
+                    number=4,
+                    message="Document.Page.DetectedLanguage",
                 )
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             header_rows = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.Table.TableRow",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Table.TableRow",
             )
             body_rows = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.Table.TableRow",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.Table.TableRow",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=4,
+                message="Document.Page.DetectedLanguage",
             )
 
         class FormField(proto.Message):
@@ -602,20 +739,33 @@ class Document(proto.Message):
             """
 
             field_name = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             field_value = proto.Field(
-                proto.MESSAGE, number=2, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Layout",
             )
             name_detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
             value_detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=4,
+                message="Document.Page.DetectedLanguage",
+            )
+            value_type = proto.Field(
+                proto.STRING,
+                number=5,
             )
-            value_type = proto.Field(proto.STRING, number=5,)
             provenance = proto.Field(
-                proto.MESSAGE, number=8, message="Document.Provenance",
+                proto.MESSAGE,
+                number=8,
+                message="Document.Provenance",
             )
 
         class DetectedLanguage(proto.Message):
@@ -630,47 +780,88 @@ class Document(proto.Message):
                     Confidence of detected language. Range [0, 1].
             """
 
-            language_code = proto.Field(proto.STRING, number=1,)
-            confidence = proto.Field(proto.FLOAT, number=2,)
+            language_code = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            confidence = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
 
-        page_number = proto.Field(proto.INT32, number=1,)
-        image = proto.Field(proto.MESSAGE, number=13, message="Document.Page.Image",)
+        page_number = proto.Field(
+            proto.INT32,
+            number=1,
+        )
+        image = proto.Field(
+            proto.MESSAGE,
+            number=13,
+            message="Document.Page.Image",
+        )
         transforms = proto.RepeatedField(
-            proto.MESSAGE, number=14, message="Document.Page.Matrix",
+            proto.MESSAGE,
+            number=14,
+            message="Document.Page.Matrix",
         )
         dimension = proto.Field(
-            proto.MESSAGE, number=2, message="Document.Page.Dimension",
+            proto.MESSAGE,
+            number=2,
+            message="Document.Page.Dimension",
+        )
+        layout = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message="Document.Page.Layout",
         )
-        layout = proto.Field(proto.MESSAGE, number=3, message="Document.Page.Layout",)
         detected_languages = proto.RepeatedField(
-            proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+            proto.MESSAGE,
+            number=4,
+            message="Document.Page.DetectedLanguage",
         )
         blocks = proto.RepeatedField(
-            proto.MESSAGE, number=5, message="Document.Page.Block",
+            proto.MESSAGE,
+            number=5,
+            message="Document.Page.Block",
         )
         paragraphs = proto.RepeatedField(
-            proto.MESSAGE, number=6, message="Document.Page.Paragraph",
+            proto.MESSAGE,
+            number=6,
+            message="Document.Page.Paragraph",
         )
         lines = proto.RepeatedField(
-            proto.MESSAGE, number=7, message="Document.Page.Line",
+            proto.MESSAGE,
+            number=7,
+            message="Document.Page.Line",
         )
         tokens = proto.RepeatedField(
-            proto.MESSAGE, number=8, message="Document.Page.Token",
+            proto.MESSAGE,
+            number=8,
+            message="Document.Page.Token",
         )
         visual_elements = proto.RepeatedField(
-            proto.MESSAGE, number=9, message="Document.Page.VisualElement",
+            proto.MESSAGE,
+            number=9,
+            message="Document.Page.VisualElement",
         )
         tables = proto.RepeatedField(
-            proto.MESSAGE, number=10, message="Document.Page.Table",
+            proto.MESSAGE,
+            number=10,
+            message="Document.Page.Table",
         )
         form_fields = proto.RepeatedField(
-            proto.MESSAGE, number=11, message="Document.Page.FormField",
+            proto.MESSAGE,
+            number=11,
+            message="Document.Page.FormField",
         )
         symbols = proto.RepeatedField(
-            proto.MESSAGE, number=12, message="Document.Page.Symbol",
+            proto.MESSAGE,
+            number=12,
+            message="Document.Page.Symbol",
         )
         provenance = proto.Field(
-            proto.MESSAGE, number=16, message="Document.Provenance",
+            proto.MESSAGE,
+            number=16,
+            message="Document.Provenance",
         )
 
     class Entity(proto.Message):
@@ -684,7 +875,7 @@ class Document(proto.Message):
                 into the
                 [Document.text][google.cloud.documentai.v1.Document.text].
             type_ (str):
-                Entity type from a schema e.g. ``Address``.
+                Required. Entity type from a schema e.g. ``Address``.
             mention_text (str):
                 Optional. Text value in the document e.g.
                 ``1600 Amphitheatre Pkwy``. If the entity is not present in
@@ -798,30 +989,65 @@ class Document(proto.Message):
                 oneof="structured_value",
                 message=postal_address_pb2.PostalAddress,
             )
-            boolean_value = proto.Field(proto.BOOL, number=6, oneof="structured_value",)
-            text = proto.Field(proto.STRING, number=1,)
+            boolean_value = proto.Field(
+                proto.BOOL,
+                number=6,
+                oneof="structured_value",
+            )
+            text = proto.Field(
+                proto.STRING,
+                number=1,
+            )
 
         text_anchor = proto.Field(
-            proto.MESSAGE, number=1, message="Document.TextAnchor",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor",
+        )
+        type_ = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        mention_text = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        mention_id = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        confidence = proto.Field(
+            proto.FLOAT,
+            number=5,
         )
-        type_ = proto.Field(proto.STRING, number=2,)
-        mention_text = proto.Field(proto.STRING, number=3,)
-        mention_id = proto.Field(proto.STRING, number=4,)
-        confidence = proto.Field(proto.FLOAT, number=5,)
         page_anchor = proto.Field(
-            proto.MESSAGE, number=6, message="Document.PageAnchor",
+            proto.MESSAGE,
+            number=6,
+            message="Document.PageAnchor",
+        )
+        id = proto.Field(
+            proto.STRING,
+            number=7,
         )
-        id = proto.Field(proto.STRING, number=7,)
         normalized_value = proto.Field(
-            proto.MESSAGE, number=9, message="Document.Entity.NormalizedValue",
+            proto.MESSAGE,
+            number=9,
+            message="Document.Entity.NormalizedValue",
         )
         properties = proto.RepeatedField(
-            proto.MESSAGE, number=10, message="Document.Entity",
+            proto.MESSAGE,
+            number=10,
+            message="Document.Entity",
         )
         provenance = proto.Field(
-            proto.MESSAGE, number=11, message="Document.Provenance",
+            proto.MESSAGE,
+            number=11,
+            message="Document.Provenance",
+        )
+        redacted = proto.Field(
+            proto.BOOL,
+            number=12,
         )
-        redacted = proto.Field(proto.BOOL, number=12,)
 
     class EntityRelation(proto.Message):
         r"""Relationship between
@@ -836,9 +1062,18 @@ class Document(proto.Message):
                 Relationship description.
         """
 
-        subject_id = proto.Field(proto.STRING, number=1,)
-        object_id = proto.Field(proto.STRING, number=2,)
-        relation = proto.Field(proto.STRING, number=3,)
+        subject_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        object_id = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        relation = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
     class TextAnchor(proto.Message):
         r"""Text reference indexing into the
@@ -872,13 +1107,24 @@ class Document(proto.Message):
                     [Document.text][google.cloud.documentai.v1.Document.text].
             """
 
-            start_index = proto.Field(proto.INT64, number=1,)
-            end_index = proto.Field(proto.INT64, number=2,)
+            start_index = proto.Field(
+                proto.INT64,
+                number=1,
+            )
+            end_index = proto.Field(
+                proto.INT64,
+                number=2,
+            )
 
         text_segments = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="Document.TextAnchor.TextSegment",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor.TextSegment",
+        )
+        content = proto.Field(
+            proto.STRING,
+            number=2,
         )
-        content = proto.Field(proto.STRING, number=2,)
 
     class PageAnchor(proto.Message):
         r"""Referencing the visual context of the entity in the
@@ -930,18 +1176,33 @@ class Document(proto.Message):
                 TABLE = 6
                 FORM_FIELD = 7
 
-            page = proto.Field(proto.INT64, number=1,)
+            page = proto.Field(
+                proto.INT64,
+                number=1,
+            )
             layout_type = proto.Field(
-                proto.ENUM, number=2, enum="Document.PageAnchor.PageRef.LayoutType",
+                proto.ENUM,
+                number=2,
+                enum="Document.PageAnchor.PageRef.LayoutType",
+            )
+            layout_id = proto.Field(
+                proto.STRING,
+                number=3,
             )
-            layout_id = proto.Field(proto.STRING, number=3,)
             bounding_poly = proto.Field(
-                proto.MESSAGE, number=4, message=geometry.BoundingPoly,
+                proto.MESSAGE,
+                number=4,
+                message=geometry.BoundingPoly,
+            )
+            confidence = proto.Field(
+                proto.FLOAT,
+                number=5,
             )
-            confidence = proto.Field(proto.FLOAT, number=5,)
 
         page_refs = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="Document.PageAnchor.PageRef",
+            proto.MESSAGE,
+            number=1,
+            message="Document.PageAnchor.PageRef",
         )
 
     class Provenance(proto.Message):
@@ -991,17 +1252,36 @@ class Document(proto.Message):
                     The id of the parent provenance.
             """
 
-            revision = proto.Field(proto.INT32, number=1,)
-            index = proto.Field(proto.INT32, number=3,)
-            id = proto.Field(proto.INT32, number=2,)
+            revision = proto.Field(
+                proto.INT32,
+                number=1,
+            )
+            index = proto.Field(
+                proto.INT32,
+                number=3,
+            )
+            id = proto.Field(
+                proto.INT32,
+                number=2,
+            )
 
-        revision = proto.Field(proto.INT32, number=1,)
-        id = proto.Field(proto.INT32, number=2,)
+        revision = proto.Field(
+            proto.INT32,
+            number=1,
+        )
+        id = proto.Field(
+            proto.INT32,
+            number=2,
+        )
         parents = proto.RepeatedField(
-            proto.MESSAGE, number=3, message="Document.Provenance.Parent",
+            proto.MESSAGE,
+            number=3,
+            message="Document.Provenance.Parent",
         )
         type_ = proto.Field(
-            proto.ENUM, number=4, enum="Document.Provenance.OperationType",
+            proto.ENUM,
+            number=4,
+            enum="Document.Provenance.OperationType",
         )
 
     class Revision(proto.Message):
@@ -1051,18 +1331,42 @@ class Document(proto.Message):
                     is ``rejected``.
             """
 
-            state = proto.Field(proto.STRING, number=1,)
-            state_message = proto.Field(proto.STRING, number=2,)
+            state = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            state_message = proto.Field(
+                proto.STRING,
+                number=2,
+            )
 
-        agent = proto.Field(proto.STRING, number=4, oneof="source",)
-        processor = proto.Field(proto.STRING, number=5, oneof="source",)
-        id = proto.Field(proto.STRING, number=1,)
-        parent = proto.RepeatedField(proto.INT32, number=2,)
+        agent = proto.Field(
+            proto.STRING,
+            number=4,
+            oneof="source",
+        )
+        processor = proto.Field(
+            proto.STRING,
+            number=5,
+            oneof="source",
+        )
+        id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        parent = proto.RepeatedField(
+            proto.INT32,
+            number=2,
+        )
         create_time = proto.Field(
-            proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=3,
+            message=timestamp_pb2.Timestamp,
         )
         human_review = proto.Field(
-            proto.MESSAGE, number=6, message="Document.Revision.HumanReview",
+            proto.MESSAGE,
+            number=6,
+            message="Document.Revision.HumanReview",
         )
 
     class TextChange(proto.Message):
@@ -1083,27 +1387,78 @@ class Document(proto.Message):
         """
 
         text_anchor = proto.Field(
-            proto.MESSAGE, number=1, message="Document.TextAnchor",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor",
+        )
+        changed_text = proto.Field(
+            proto.STRING,
+            number=2,
         )
-        changed_text = proto.Field(proto.STRING, number=2,)
         provenance = proto.RepeatedField(
-            proto.MESSAGE, number=3, message="Document.Provenance",
+            proto.MESSAGE,
+            number=3,
+            message="Document.Provenance",
         )
 
-    uri = proto.Field(proto.STRING, number=1, oneof="source",)
-    content = proto.Field(proto.BYTES, number=2, oneof="source",)
-    mime_type = proto.Field(proto.STRING, number=3,)
-    text = proto.Field(proto.STRING, number=4,)
-    text_styles = proto.RepeatedField(proto.MESSAGE, number=5, message=Style,)
-    pages = proto.RepeatedField(proto.MESSAGE, number=6, message=Page,)
-    entities = proto.RepeatedField(proto.MESSAGE, number=7, message=Entity,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="source",
+    )
+    content = proto.Field(
+        proto.BYTES,
+        number=2,
+        oneof="source",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    text = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    text_styles = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=Style,
+    )
+    pages = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message=Page,
+    )
+    entities = proto.RepeatedField(
+        proto.MESSAGE,
+        number=7,
+        message=Entity,
+    )
     entity_relations = proto.RepeatedField(
-        proto.MESSAGE, number=8, message=EntityRelation,
+        proto.MESSAGE,
+        number=8,
+        message=EntityRelation,
+    )
+    text_changes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=14,
+        message=TextChange,
+    )
+    shard_info = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=ShardInfo,
+    )
+    error = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=status_pb2.Status,
+    )
+    revisions = proto.RepeatedField(
+        proto.MESSAGE,
+        number=13,
+        message=Revision,
     )
-    text_changes = proto.RepeatedField(proto.MESSAGE, number=14, message=TextChange,)
-    shard_info = proto.Field(proto.MESSAGE, number=9, message=ShardInfo,)
-    error = proto.Field(proto.MESSAGE, number=10, message=status_pb2.Status,)
-    revisions = proto.RepeatedField(proto.MESSAGE, number=13, message=Revision,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
