@@ -1086,9 +1086,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
